package gin_gonic

import (
	"os"

	"git.home.m-and-m.ovh/mderasse/gouick/helpers"
	"git.home.m-and-m.ovh/mderasse/gouick/helpers/models"

	"github.com/juju/errors"
	log "github.com/sirupsen/logrus"
)

// GetInitializeUserInput
func (a ApiType) GetInitializeUserInput() (*models.UserInputParams, error) {

	log.Debug("Starting Gin Gonic user input")

	// Initialize a default userInput
	userInput := models.UserInputParams{
		DB: false,
	}

	// Get current path
	log.Debug("Getting current location")

	currentPath, err := os.Getwd()
	if err != nil {
		log.Errorf("Fail to get current path. The following error happen: %s", err.Error())
		return nil, errors.Trace(err)
	}

	// Check if we are in a go project already
	log.Debug("Checking if we are in a Go Project")

	isGoProject, err := helpers.IsGoProject(currentPath)
	if err != nil {
		log.Errorf("Fail to check if we are in a Go Project. The following error happen: %s", err.Error())
		return nil, errors.Trace(err)
	}

	if isGoProject {
		log.Error("We already are in a golang project directory")
		return nil, errors.NotValidf("We already are in a golang project directory")
	}

	// Check if we are in gopath
	log.Debug("Checking if we are in GoPath")

	isInGoPath := helpers.IsInGoPath(currentPath)
	if !isInGoPath {

		log.Debug("We are not in GoPath, ask extra info")
		goModulePath := helpers.StringInput()
		userInput.GoModuleName = &goModulePath
	}

	log.Info("Do you want to enable database integration ?")
	userInput.DB = helpers.YesOrNoInput()

	return &userInput, nil
}
